@@ -12,6 +12,7 @@ class RecommendationsManager(Manager):
     """
         Manages retrieval of Personalize recommendations for a given set of parameters
     """
+    # pylint: disable=raise-missing-from
     def get_recommendations(self):
         """
             Get the recommendations for the specified parameters
@@ -67,6 +68,7 @@ class RecommendationsManager(Manager):
 
         queue_utils.queue_s3_recommendations_store(
             client=client,
+            engine='personalize',
             results=results,
             item_id=item_id,
             context=self.parameters.get('context', {})
