@@ -143,11 +143,6 @@ class DatasetStateManager:
             blob, bucket, file_path
         )
 
-    def download_json_blob(self, s3_url: str):
-        """download json data from s3"""
-        data_stream = self.download_s3_blob(s3_url=s3_url)
-        return json.loads(data_stream.read().decode("UTF-8"))
-
     def execute_s3_versioning(self, data_stream: io.BytesIO, dst_url: str):
         """
             Streams data from source s3 url to a destination s3 url
@@ -171,13 +166,19 @@ class DatasetStateManager:
             else:
                 raise
 
-    def cache_lookup(self, json_data: dict, cache_key: str):
+    def cache_lookup(self, data_stream: io.BytesIO, cache_key: str):
         """cache lookup in elasticcache
 
         Args:
             cache_key (str): key to use when caching
             json_data (dict): data to cache which should be simple dictionary lookup
         """
+        json_data = json.loads(
+            data_stream.read().decode("UTF-8")
+        )
+        if not isinstance(json_data, dict):
+            raise Exception("ClientError: Json data is not a dictionary")
+
         if self.redis_helper.redis_hexists(hashkey=cache_key) == 1:
             print("This cache already exists. Deleting before caching new data")
             self.redis_helper.redis_delete(keys=[cache_key])
@@ -323,32 +324,27 @@ class DatasetStateManager:
 
                 print("Download dataset from prod/ in s3")
 
-                json_data = self.download_json_blob(s3_url=prod_url)
-
-                if not isinstance(json_data, dict):
-                    raise Exception("ClientError: Json data is not a dictionary")
+                data_stream = self.download_s3_blob(s3_url=prod_url)
 
                 print("Pushing to previous/ to s3")
                 self.execute_s3_versioning(
-                    data_stream=json_data,
+                    data_stream=data_stream,
                     dst_url=previous_url
                 )
 
                 print("Download dataset from train/ from s3")
                 # get data
-                json_data = self.download_json_blob(s3_url=identifier)
+                data_stream = self.download_s3_blob(s3_url=identifier)
 
-                if not isinstance(json_data, dict):
-                    raise Exception("ClientError: Json data is not a dictionary")
                 # cache to elastic cache
                 print("Caching new prod dataset")
                 self.cache_lookup(
-                    json_data=json_data,
+                    data_stream=data_stream,
                     cache_key=cache_key
                 )
                 print("Pushing dataset to prod/ in s3")
                 self.execute_s3_versioning(
-                    data_stream=json_data,
+                    data_stream=data_stream,
                     dst_url=prod_url
                 )
 
